@@ -180,7 +180,7 @@ class Command(BaseCommand):
         self.log_pauses()
 
 
-        self.recruit()
+        self.recruit(headcount=randint(10, 50))
         self.pay_salaries()
 
     def create_family_tax_discount_statements(self):
@@ -797,14 +797,24 @@ class Command(BaseCommand):
         begin = datetime(year=year, month=month, day=1)
         end = datetime(year=year, month=month, day=calendar.monthrange(year, month)[1])
         for day in range(begin.day, end.day):
-            category = choice(TimeSheetCategory.objects.all())
+            presense_category = choice(TimeSheetCategory.objects.all())
+            absense_category = choice(PauseCategory.objects.all())
+
             time = timedelta(hours=randint(2, 12))
-            TimeSheetItem.objects.create(
-                category=category,
-                sheet=sheet,
-                timestamp=datetime(year=year, month=month, day=day),
-                duration=time
-            )
+            if choice([True, False]):
+                TimeSheetItem.objects.create(
+                    presence=presense_category,
+                    sheet=sheet,
+                    timestamp=datetime(year=year, month=month, day=day),
+                    duration=time
+                )
+            else:
+                TimeSheetItem.objects.create(
+                    absence=absense_category,
+                    sheet=sheet,
+                    timestamp=datetime(year=year, month=month, day=day),
+                    duration=time
+                )
         salary.timesheet = sheet
         salary.save()
 
