@@ -6,4 +6,4 @@ from django.utils.translation import ugettext_lazy as _
 class MasterdataConfig(ModuleMixin, AppConfig):
     name = 'masterdata'
     verbose_name = _('Törzsadat')
-    icon = '<i class="material-icons">settings_applications</i>'
+    icon = '<i class="material-icons">library_books</i>'
